==> eam-wshub-proxyclient-11.4-0-sources.jar: net/datastream/schemas/mp_fields/ASSOCIATECUSTFIELD_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for ASSOCIATECUSTFIELD_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="ASSOCIATECUSTFIELD_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CUSTOMFIELDELEMENTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ENTITY"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CLASSID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ASSOCIATECUSTFIELD_Type", propOrder = {
    "customfieldelementid",
    "entity",
    "classid"
})
public class ASSOCIATECUSTFIELD_Type {

    @XmlElement(name = "CUSTOMFIELDELEMENTID", required = true)
    protected CUSTOMFIELDELEMENTID_Type customfieldelementid;
    @XmlElement(name = "ENTITY", required = true)
    protected String entity;
    @XmlElement(name = "CLASSID", required = true)
    protected CLASSID_Type classid;

    /**
     * Gets the value of the customfieldelementid property.
     * 
     * @return
     *     possible object is
     *     {@link CUSTOMFIELDELEMENTID_Type }
     *     
     */
    public CUSTOMFIELDELEMENTID_Type getCUSTOMFIELDELEMENTID() {
        return customfieldelementid;
    }

    /**
     * Sets the value of the customfieldelementid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CUSTOMFIELDELEMENTID_Type }
     *     
     */
    public void setCUSTOMFIELDELEMENTID(CUSTOMFIELDELEMENTID_Type value) {
        this.customfieldelementid = value;
    }

    /**
     * Gets the value of the entity property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getENTITY() {
        return entity;
    }

    /**
     * Sets the value of the entity property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setENTITY(String value) {
        this.entity = value;
    }

    /**
     * Gets the value of the classid property.
     * 
     * @return
     *     possible object is
     *     {@link CLASSID_Type }
     *     
     */
    public CLASSID_Type getCLASSID() {
        return classid;
    }

    /**
     * Sets the value of the classid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CLASSID_Type }
     *     
     */
    public void setCLASSID(CLASSID_Type value) {
        this.classid = value;
    }

}

==> eam-wshub-proxyclient-11.4-5-sources.jar: net/datastream/schemas/mp_fields/ASSOCIATECUSTFIELD_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour ASSOCIATECUSTFIELD_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="ASSOCIATECUSTFIELD_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CUSTOMFIELDELEMENTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ENTITY"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CLASSID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ASSOCIATECUSTFIELD_Type", propOrder = {
    "customfieldelementid",
    "entity",
    "classid"
})
public class ASSOCIATECUSTFIELD_Type {

    @XmlElement(name = "CUSTOMFIELDELEMENTID", required = true)
    protected CUSTOMFIELDELEMENTID_Type customfieldelementid;
    @XmlElement(name = "ENTITY", required = true)
    protected String entity;
    @XmlElement(name = "CLASSID", required = true)
    protected CLASSID_Type classid;

    /**
     * Obtient la valeur de la propriété customfieldelementid.
     * 
     * @return
     *     possible object is
     *     {@link CUSTOMFIELDELEMENTID_Type }
     *     
     */
    public CUSTOMFIELDELEMENTID_Type getCUSTOMFIELDELEMENTID() {
        return customfieldelementid;
    }

    /**
     * Définit la valeur de la propriété customfieldelementid.
     * 
     * @param value
     *     allowed object is
     *     {@link CUSTOMFIELDELEMENTID_Type }
     *     
     */
    public void setCUSTOMFIELDELEMENTID(CUSTOMFIELDELEMENTID_Type value) {
        this.customfieldelementid = value;
    }

    /**
     * Obtient la valeur de la propriété entity.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getENTITY() {
        return entity;
    }

    /**
     * Définit la valeur de la propriété entity.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setENTITY(String value) {
        this.entity = value;
    }

    /**
     * Obtient la valeur de la propriété classid.
     * 
     * @return
     *     possible object is
     *     {@link CLASSID_Type }
     *     
     */
    public CLASSID_Type getCLASSID() {
        return classid;
    }

    /**
     * Définit la valeur de la propriété classid.
     * 
     * @param value
     *     allowed object is
     *     {@link CLASSID_Type }
     *     
     */
    public void setCLASSID(CLASSID_Type value) {
        this.classid = value;
    }

}
